#!/bin/sh
set -x

# make sure executable exists
if [ x"$1" = x ]; then
  echo "usage: $0 program program_args"
  exit 1
fi
if [ ! -x "$1" ]; then
  echo "ERROR: can't find executable: $1"
  exit 1
fi
EXE="$1"
shift

# for initialization, start in directory containng this script
CURDIR="`dirname \"$0\"`"
cd $CURDIR

# make sure display is set by starting X11 and letting the getdisplay.sh
# script tell us the DISPLAY value. Thanks for the code fragment:
# Edd Edmondson (Oxford Astrophysics) and Aaron Voisine (aaron@voisine.org)
open-x11 ./scripts/getdisplay.sh
while [ "$?" == "0" -a ! -f /tmp/display.$UID ]; do
  sleep 1
done
export "DISPLAY=`cat /tmp/display.$UID`"
rm -f /tmp/display.$UID

# initialization we need before executing the command
SH="`./scripts/getshell.sh`"
INIT="`./scripts/getshellinit.sh $SH`"

# if we have file arguments, if ds9 is already running, and if xpa is
# xpa is available, just send the file name(s) (ie mimick drag and drop)
if [ x"$1" != x ]; then
  eval "`./scripts/getshellinit.sh /bin/sh`"
  XPA=`xpaget xpans | egrep DS9 | egrep $USER | awk '{print $4}'`
  if [ x"$XPA" != x ]; then
    for file in $@;
    do
      if [ x"$last" != x ]; then
        new="new"
      fi
      xpaset -p $XPA file $new $file
      last=$file
    done    
    exit 0
  fi
fi

# for execution, start in home directory
cd $HOME

# this is the command we will execute
CMD="$INIT $EXE $@"

# start program using the user's shell
$SH -c "$CMD" &
